** Replication Code for Xu and Yao (2015) 
** Informal Institutions, Collective Action, and Public Investment in Rural China

clear all
set more off

********************************
* Table 1: descriptive stat
********************************

use XuYao2015_informal, clear
tabstat inv loginv log_levies ///
     logpopl logincome logasset hhsize landpc logmigration logtax logtransfer share_admin  ///
	 postcont postopen secret_ballot proxy_voting moving_ballot ///
	 , s(N mean sd min max) c(s)

use XuYao2015_informal, clear
keep if elecyr==1	 
tabstat vcfirst vcsecond vcfirst2 vc_char_* vote ///
        psfirst2 vcps_clan vcps_person vc_pb ///
		, s(N mean sd min max) c(s)
        
use XuYao2015_informal, clear
keep if year==2005
tabstat clan_num clansz* largeclan family_tree ances_hall, s(N mean sd min max) c(s)
     
********************************
* Table 2: baseline resutls
********************************

use XuYao2015_informal, clear

areg loginv vcfirst vcsecond, a(year) cl(vill_id)

areg loginv vcfirst vcsecond i.year, a(vill_id) cl(vill_id)

areg loginv vcfirst vcsecond i.year i.prov_id#c.year, a(vill_id) cl(vill_id)

areg loginv vcfirst vcsecond i.year c.year#i.vill_id, a(vill_id) cl(vill_id)

areg loginv vcfirst vcsecond hhsize landpc logpopl logincome logasset i.year i.prov_id#c.year, a(vill_id) cl(vill_id)

areg loginv vcfirst vcsecond hhsize landpc logpopl logincome logasset logmigration logtax logtransfer i.year i.prov_id#c.year, a(vill_id) cl(vill_id)


***********************************
* Figure 2: lineage organizations
***********************************

use lineageorg, clear
graph bar citang cerem citanghis, over(clan)


***********************************
* Figure 3: dynamic effect
***********************************

use XuYao2015_informal, clear

areg loginv vc_in_office* i.year, a(vill_id) cl(vill_id)


********************************
* Table 3: by category
********************************

use XuYao2015_informal, clear

foreach var in loginv_cat_* {
  areg `var' vcfirst2 i.year, a(vill_id) cl(vill_id)
}


***************************************
* Figure 4: clan size and cohesiveness
***************************************
 
use XuYao2015_informal, clear

areg loginv  vcfirst2##largeclan i.year, a(vill_id) cl(vill_id)
 
areg loginv vcfirst2##family_tree i.year, a(vill_id) cl(vill_id)

areg loginv vcfirst2##ances_hall i.year, a(vill_id) cl(vill_id)

areg loginv vcfirst2##(largeclan family_tre ances_hall) i.year, a(vill_id) cl(vill_id)


***********************************
* Figure 5: party
***********************************

use XuYao2015_informal, clear

* party secretary   
areg loginv vcfirst2##psfirst2 i.year, a(vill_id) cl(vill_id)

* one-shoulder
areg loginv vcfirst2##psfirst2##vcps_person i.year, a(vill_id) cl(vill_id)

* same clan
areg loginv vcfirst2##psfirst2##vcps_clan i.year, a(vill_id) cl(vill_id)

* in party branch
areg loginv vcfirst2##psfirst2##vc_pb i.year, a(vill_id) cl(vill_id)



***********************************
* Figure 6: RD Design
***********************************

use XuYao2015_informal, clear
keep if !inlist(vote,0,1)

* histgram
hist vote

* create 5% vote bin
egen vote_bin = cut(vote), at(0(0.05)1)
replace vote_bin = vote_bin + 0.025
tab vote_bin

* take out fixed effects and provincial trends
qui reg loginv i.vill_id i.year i.prov_id#c.year
predict loginv_ad if e(sample), residuals

* average within bins
bysort vote_bin: egen avg_loginv_ad = mean(loginv_ad)

* scatter plot
twoway sc avg_loginv_ad vote_bin || ///
       lowess loginv_ad vote if vcfirst2==0, lc(navy) || ///
       lowess loginv_ad vote if vcfirst2==1, lc(navy) ///
	   , ylabel(-1.5(0.5)1.5) legend(off) 
	   
* do the same for investment dummy (Figure A4)
qui reg inv i.vill_id i.year i.prov_id#c.year
predict inv_ad if e(sample), residuals
bysort vote_bin: egen avg_inv_ad = mean(inv_ad)

twoway sc avg_inv_ad vote_bin || ///
       lowess inv_ad vote if vcfirst2==0, lc(navy) || ///
       lowess inv_ad vote if vcfirst2==1, lc(navy) ///
	   , ylabel(-0.4(0.1)0.4) legend(off) 	   

	   
********************************
* Table 4: levies
********************************

* RCRE did not run surveys in 1992 and 1994

use XuYao2015_informal, clear
g vcfirst2_inv=vcfirst2*finv

areg log_levies vcfirst2 i.year, a(vill_id) cl(vill_id)

areg log_levies finv i.year, a(vill_id) cl(vill_id)

areg log_levies vcfirst2 finv vcfirst2_inv   i.year, a(vill_id) cl(vill_id)

*************************************************************
* Figure 7: levies on HHs with various income percentile 
*************************************************************

* RCRE did not run surveys in 1992 and 1994

use XuYao2015_informal, clear

foreach var of varlist log_levies_p* {
    areg `var' finv i.year, a(vill_id) cl(vill_id)
}


********************************
* Table 5: administrative cost
********************************

* RCRE did not run surveys in 1992 and 1994

use XuYao2015_informal, clear

areg share_admin vcfirst2 `x' i.year, a(vill_id) cl(vill_id)

areg log_admin vcfirst2 `x' i.year, a(vill_id) cl(vill_id)


********************************
* Table 6: VC characteristics
********************************

use XuYao2015_informal, clear

areg loginv vcfirst2 vc_char_educ i.year, a(vill_id) cl(vill_id)

areg loginv vcfirst2 vc_char_educ vc_char_age vc_char_ccp vc_char_cadre vc_char_manager vc_char_exper i.year, a(vill_id) cl(vill_id)

areg loginv vcfirst2 vc_char_* i.year, a(vill_id) cl(vill_id)


***********************************
* Table 7: electoral institutions
***********************************
 
use XuYao2015_informal, clear

areg loginv vcfirst2 postcont i.year, a(vill_id) cl(vill_id)

areg loginv vcfirst2 postopen i.year, a(vill_id) cl(vill_id)

areg loginv vcfirst2 secret_ballot i.year, a(vill_id) cl(vill_id)

areg loginv vcfirst2 proxy_voting i.year, a(vill_id) cl(vill_id)

areg loginv vcfirst2 moving_ballot i.year, a(vill_id) cl(vill_id)

areg loginv vcfirst2 i.year if postcont==1, a(vill_id) cl(vill_id)

areg loginv vcfirst2 i.year if postopen==1, a(vill_id) cl(vill_id)


